BusLegReceiver

Struct BusLegReceiver 

pub struct BusLegReceiver<ChannelId, MSG, const STATIC_SIZE: usize> { /* private fields */ }
A receiver for a bus leg.

This struct is used to receive messages from a bus leg. It holds a queue of messages that have been sent to the bus leg.

Implementations

Source

impl<ChannelId, MSG, const STATIC_SIZE: usize> BusLegReceiver<ChannelId, MSG, STATIC_SIZE>

pub fn recv(&self) -> Option<(BusEventSource<ChannelId>, MSG)>

Receives a message from the bus leg.

Returns

Returns Some((source, msg)) if there is a message in the queue, where source is the source of the bus event and msg is the received message. Returns None if the queue is empty.

pub fn set_awaker(&self, awaker: Arc<dyn Awaker>)