DynamicDeque

Struct DynamicDeque 

pub struct DynamicDeque<T, const STACK_SIZE: usize> { /* private fields */ }
A dynamic deque that can store elements in a stack or a heap. First, elements are pushed to the stack. If the stack is full, elements are pushed to the heap. When popping elements, the stack is popped first. If the stack is empty and the heap is not, the heap is popped and the elements are pushed to the stack. Example:

use sans_io_runtime::collections::DynamicDeque;
let mut deque: DynamicDeque<i32, 5> = DynamicDeque::default();
deque.push_back_stack(1).unwrap();
deque.push_back_stack(2).unwrap();
deque.push_back_stack(3).unwrap();
deque.push_back_stack(4).unwrap();
deque.push_back_stack(5).unwrap();
deque.push_back(6); // Should overflow to heap
assert_eq!(deque.len(), 6);

Implementations

Source

impl<T, const STATIC_SIZE: usize> DynamicDeque<T, STATIC_SIZE>

pub fn from<const SIZE: usize>(prepare: [T; SIZE]) -> Self

Creates a new instance of DynamicDeque from an array of elements.

Arguments
  • prepare - An array of elements to initialize the deque with.
Returns

A new instance of DynamicDeque.

pub fn push_back_stack(&mut self, value: T) -> Result<(), T>

Pushes an element to the stack of the deque.

Arguments
  • value - The value to be pushed.
Returns
  • Ok(()) - If the element was successfully pushed.
  • Err(value) - If the element could not be pushed due to overflow.
pub fn push_back(&mut self, value: T)

Pushes an element to the stack or the heap of the deque.

Arguments
  • value - The value to be pushed.
pub fn pop_front(&mut self) -> Option<T>

Pops the element from the front of the deque.

Returns

The popped element, or None if the deque is empty.

pub fn is_empty(&self) -> bool

Checks if the deque is empty.

Returns

true if the deque is empty, false otherwise.

pub fn len(&self) -> usize

Returns the number of elements in the deque.

Returns

The number of elements in the deque.

pub fn pop2(&mut self, e: T) -> T

This is useful in task where we usually doing output in queue We need push to back then immediate pop from front